Learn R Programming

NMF (version 0.3.1)

NMF-deprecated: Deprecated Functions in NMF Package

Description

These functions are provided for compatibility with older versions of NMF package only, and may be defunct as soon as the next release.

Usage

## S3 method for class 'NMF':
clusters(x, what = c('samples', 'features'))

Arguments

what
Specifies on which matrix (basis components or mixture coefficients) the computation should be performed.
x
An object that inherits from class NMF.

Details

clusters is a deprecated synonym for predict.